@@ -22,7 +22,7 @@ SentryToken = models.SentryToken
 DatabaseCredential = models.DatabaseCredential
 
 
-class CredentialManager(object):
+class CredentialManager:
     """The CredentialManager class provides a way to interact with CredentialManager's API.
 
     The official way to initialize an instance of this class is to:
@@ -69,7 +69,7 @@ class CredentialManager(object):
             resource_type = data.get("resource_type", "")
             model = getattr(models, resource_type, None)
             data = self._inject(data)
-            return model.schema.load(data) if model else data
+            return model.schema().load(data) if model else data
 
     def _inject(self, data: dict):
         """Injects the credential manager into the data.
@@ -163,12 +163,10 @@ class CredentialManager(object):
                 exc.message += "\nYou provided the name of a .credmgr.ini section that doesn't exist."
             raise
 
-        self._server = _urljoin(
-            getattr(self.config, "server"), getattr(self.config, "endpoint")
-        )
-        api_token = getattr(self.config, "api_token")
-        username = getattr(self.config, "username")
-        password = getattr(self.config, "password")
+        self._server = _urljoin(self.config.server, self.config.endpoint)
+        api_token = self.config.api_token
+        username = self.config.username
+        password = self.config.password
 
         init_error_message = "Required settings are missing. Either 'api_token' OR 'username' and 'password' must be specified, These settings can be provided in a .credmgr.ini file, as a keyword argument during the initialization of the `CredentialManager` class, or as an environment variable."
         if all([api_token, username, password]):
