@@ -1,4 +1,5 @@
 """Provide the Bot class."""
+
 from ..deprecation_decorator import warn_camel_case
 from ..mixins import BaseApp
 from .utils import _resolve_user
@@ -41,7 +42,6 @@ class Bot(BaseApp):
     _path = "/bots"
 
     @classmethod
-    @property
     def schema(cls):
         """Return the schema for this model."""
         if cls._schema is None:
@@ -136,7 +136,7 @@ class Bot(BaseApp):
         """
         from . import DatabaseCredential, RedditApp, SentryToken
 
-        for key, value in list(kwargs.items()):
+        for key, _value in list(kwargs.items()):
             if key in ["reddit_app", "sentry_token", "database_credential"]:
                 if isinstance(
                     kwargs[key], (RedditApp, SentryToken, DatabaseCredential)
