@@ -1,4 +1,5 @@
 """Provide the helper classes."""
+
 from ..deprecation_decorator import warn_camel_case
 from ..exceptions import InitializationError
 from ..mixins import BaseModel
@@ -59,7 +60,7 @@ class Paginator:
     def _next(self):
         if self._completed:
             raise StopIteration()
-        params = dict(limit=self.batch_size, offset=self._offset)
+        params = {"limit": self.batch_size, "offset": self._offset}
         if self.items_owner:
             params["owner_id"] = self.items_owner
         self._response = self._credmgr.get(self._model._path, params=params)
