@@ -1,4 +1,5 @@
 """Provide helper utilities used by other models."""
+
 from functools import wraps
 
 from credmgr.exceptions import NotFound
@@ -29,13 +30,13 @@ def _resolve_user(func):
         user = kwargs.get("owner", None)
         if user:
             if isinstance(user, User):
-                value = getattr(user, "id")
+                value = user.id
             elif isinstance(user, int):
                 value = user
             elif isinstance(user, str):
                 found_user = self._credmgr.user(user)
                 if found_user:
-                    value = getattr(found_user, "id")
+                    value = found_user.id
             kwargs["owner"] = value
         return func(self, *args, **kwargs)
 
