@@ -1,4 +1,5 @@
 """Provide the Requestor class."""
+
 import logging
 from collections import defaultdict
 
@@ -28,7 +29,7 @@ def _urljoin(base, path):
     return f"{base}{path}"
 
 
-class Requestor(object):
+class Requestor:
     """Requestor provides an interface to HTTP requests."""
 
     _exception_mapping = defaultdict(
@@ -91,7 +92,7 @@ class Requestor(object):
                     method, url, params, data=data, timeout=15, **kwargs
                 )
                 log.debug(
-                    f'Response: {response.status_code} ({response.headers.get("content-length")} bytes)'
+                    f"Response: {response.status_code} ({response.headers.get('content-length')} bytes)"
                 )
                 if response.status_code in self._exception_mapping:
                     raise self._exception_mapping[response.status_code](response)
@@ -102,13 +103,13 @@ class Requestor(object):
                 try:
                     response.json()
                 except ValueError:  # pragma: no cover
-                    raise InvalidJSON(response)
+                    raise InvalidJSON(response) from None
                 return response
             except self._retry_error as error:
                 retry_count += 1
                 if retry_count < retry_limit:
                     log.debug(
-                        f"Error occurred: {error}. Retrying...attempt {retry_count}/{retry_limit-1}"
+                        f"Error occurred: {error}. Retrying...attempt {retry_count}/{retry_limit - 1}"
                     )
                 else:
                     log.error(f"Error occurred: {error}. Max attempts reached.")
